@@ -482,8 +482,7 @@ from data.models.models import HardwareStats, DataTransformer, DataTransformerCo
 class DataConstantsTransformerForm(forms.ModelForm):
     id = forms.CharField(required=False,
                          widget=forms.HiddenInput(attrs={'class': 'form-control'}))
-    type = forms.CharField(required=False,
-                           widget=forms.TextInput(attrs={'class': 'form-control'}))
+
 
     index = forms.IntegerField(required=False,
                                widget=forms.HiddenInput(attrs={'class': 'form-control'}),
@@ -526,8 +525,8 @@ class HardwareStatsTransformerForm(forms.ModelForm):
 
 DataConstantsTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformerConstants, extra=1,
                                                               form=DataConstantsTransformerForm, can_delete_extra=True)
-HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,
-                                                         form=HardwareTransformerForm, can_delete_extra=True)
+# HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareDataTransformer, extra=1,
+#                                                          form=HardwareTransformerForm, can_delete_extra=True)
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,
                                                               form=HardwareStatsTransformerForm, can_delete_extra=True)
 
@@ -562,7 +561,7 @@ class DataTransform(forms.ModelForm):
                     queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id':str(uuid.uuid4())}],
+                    initial=[{'parent': str(self.instance.pk), 'accessory': str(self.instance.accessory.id), 'id':str(uuid.uuid4())}],
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
@@ -584,20 +583,19 @@ class DataTransform(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id)+'DataConstantsTransformerInlineFormset',
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
         self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
 
-        self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=self.instance,
-            queryset=self.instance.hardwaredatatransformer_set,
+        hardware_outputs = self.instance.hardwaredatatransformer_set.first()
+        self.nested_hardware_outputs_form = HardwareTransformerForm(
+            instance=hardware_outputs,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=str(self.instance.id)+'HardwareTransformerInlineFormset',
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            prefix=str(self.instance.id)+'HardwareTransformerForm',
+            initial={'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}
         )
-        self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
             instance=self.instance,
@@ -605,7 +603,7 @@ class DataTransform(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id)+'HardwareStatsTransformerInlineFormset',
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
         self.nested_hardware_stats_form.extra = self.instance.hardwarestatsdatatransformer_set.count() + 1
@@ -638,7 +636,7 @@ class DataTransform(forms.ModelForm):
         root_node = super(DataTransform, self).save(commit)
         if hasattr(self,
                    'nested_constants_form') and self.nested_constants_form is not None:
-            # self.nested_constants_form.instance.refresh_from_db()
+            self.nested_constants_form.instance.refresh_from_db()
             if self.nested_constants_form.is_valid():
                 self.nested_constants_form.save(commit)
             else:
@@ -653,6 +651,8 @@ class DataTransform(forms.ModelForm):
                 print(self.nested_hardware_outputs_form.errors)
         if hasattr(self,
                    'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            self.nested_hardware_stats_form.instance.refresh_from_db()
+
             if self.nested_hardware_stats_form.is_valid():
                 self.nested_hardware_stats_form.save(commit)
             else:
@@ -703,7 +703,7 @@ class DataTransformRoot(forms.ModelForm):
                     queryset=self.instance.get_children(),
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id':str(uuid.uuid4())}],
+                    initial=[{'parent': str(self.instance.pk), 'accessory': str(self.instance.accessory.id), 'id':str(uuid.uuid4())}],
                     prefix=str(self.instance.id) + 'dataTransformerInlineFormset',
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
@@ -726,20 +726,20 @@ class DataTransformRoot(forms.ModelForm):
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
             prefix=str(self.instance.id)+'DataConstantsTransformerInlineFormset',
-            initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
+            initial=[{'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}]
 
         )
         self.nested_constants_form.extra = self.instance.datatransformerconstants_set.count() + 1
 
-        self.nested_hardware_outputs_form = HardwareTransformerInlineFormset(
-            instance=self.instance,
-            queryset=self.instance.hardwaredatatransformer_set,
+
+        hardware_outputs = self.instance.hardwaredatatransformer_set.first()
+        self.nested_hardware_outputs_form = HardwareTransformerForm(
+            instance=hardware_outputs,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=str(self.instance.id)+'HardwareTransformerInlineFormset',
-            initial=[{'data_transformer': str(self.instance.id), 'id': str(uuid.uuid4())}]
+            prefix=str(self.instance.id)+'HardwareTransformerForm',
+            initial={'data_transformer': str(self.instance.pk), 'id': str(uuid.uuid4())}
         )
-        self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
 
         self.nested_hardware_stats_form = HardwareStatsTransformerInlineFormset(
             instance=self.instance,
@@ -777,14 +777,13 @@ class DataTransformRoot(forms.ModelForm):
         root_node = super(DataTransformRoot, self).save(commit)
         if hasattr(self,
                    'nested_constants_form') and self.nested_constants_form is not None:
-            # self.nested_constants_form.instance.refresh_from_db()
+            self.nested_constants_form.instance.refresh_from_db()
             if self.nested_constants_form.is_valid():
                 self.nested_constants_form.save(commit)
             else:
                 print(self.nested_constants_form.errors)
         if hasattr(self,
                    'nested_hardware_outputs_form') and self.nested_hardware_outputs_form is not None:
-            # self.nested_hardware_outputs_form.instance.refresh_from_db()
 
             if self.nested_hardware_outputs_form.is_valid():
                 self.nested_hardware_outputs_form.save(commit)
@@ -792,6 +791,8 @@ class DataTransformRoot(forms.ModelForm):
                 print(self.nested_hardware_outputs_form.errors)
         if hasattr(self,
                    'nested_hardware_stats_form') and self.nested_hardware_stats_form is not None:
+            self.nested_hardware_stats_form.instance.refresh_from_db()
+
             if self.nested_hardware_stats_form.is_valid():
                 self.nested_hardware_stats_form.save(commit)
             else:
